@@ -110,12 +110,6 @@ public class GenerateDebianFilesMojo extends AbstractMojo {
     @Parameter(property = "bin.package", required = true)
     protected String binPackageName;
     
-    /**
-     * Type of the package (e.g. 'maven' or 'ant')
-     */
-    @Parameter(property = "packageType", defaultValue = "maven")
-    protected String packageType;
-    
     /**
      * URL for downloading the source code, in the form scm:[svn|cvs]:http://xxx/
      * for downloads using a source code repository,
@@ -157,7 +151,6 @@ public class GenerateDebianFilesMojo extends AbstractMojo {
             Velocity.init(velocityProperties);
             VelocityContext context = new VelocityContext();
             context.put("package", packageName);
-            context.put("packageType", packageType);
             context.put("binPackage", binPackageName);
             context.put("packager", packager);
             context.put("packagerEmail", extractEmail(email));
@@ -239,36 +232,22 @@ public class GenerateDebianFilesMojo extends AbstractMojo {
                     buildDepends.addAll(split(substvars.getProperty("maven.DocDepends")));
                     buildDepends.addAll(split(substvars.getProperty("maven.DocOptionalDepends")));
                 }
-                if ("maven".equals(packageType)) {
-                    // Remove dependencies that are implied by maven-debian-helper
-                    for (Iterator<String> i = buildDepends.iterator(); i.hasNext();) {
-                        String dependency = i.next();
-                        if (dependency.startsWith("libmaven-clean-plugin-java") ||
-                                dependency.startsWith("libmaven-resources-plugin-java") ||
-                                dependency.startsWith("libmaven-compiler-plugin-java") ||
-                                dependency.startsWith("libmaven-jar-plugin-java") ||
-                                dependency.startsWith("libmaven-site-plugin-java") ||
-                                dependency.startsWith("libsurefire-java") ||
-                                dependency.startsWith("velocity") ||
-                                dependency.startsWith("libplexus-velocity-java")) {
-                            i.remove();
-                        }
+                // Remove dependencies that are implied by maven-debian-helper
+                for (Iterator<String> i = buildDepends.iterator(); i.hasNext();) {
+                    String dependency = i.next();
+                    if (dependency.startsWith("libmaven-clean-plugin-java") ||
+                            dependency.startsWith("libmaven-resources-plugin-java") ||
+                            dependency.startsWith("libmaven-compiler-plugin-java") ||
+                            dependency.startsWith("libmaven-jar-plugin-java") ||
+                            dependency.startsWith("libmaven-site-plugin-java") ||
+                            dependency.startsWith("libsurefire-java") ||
+                            dependency.startsWith("velocity") ||
+                            dependency.startsWith("libplexus-velocity-java")) {
+                        i.remove();
                     }
-                    if (generateJavadoc) {
-                        buildDepends.add("libmaven-javadoc-plugin-java");
-                    }
-                } else if ("ant".equals(packageType)) {
-                    // Remove dependencies that are implied by ant packaging
-                    for (Iterator<String> i = buildDepends.iterator(); i.hasNext(); ) {
-                        String dependency = i.next();
-                        if (dependency.equals("ant") ||
-                                dependency.startsWith("ant ") ||
-                                dependency.startsWith("ant-optional")) {
-                            i.remove();
-                        }
-                    }
-                    buildDepends.remove("ant");
-                    buildDepends.remove("ant-optional");
+                }
+                if (generateJavadoc) {
+                    buildDepends.add("libmaven-javadoc-plugin-java");
                 }
                 context.put("buildDependencies", buildDepends);
                 context.put("runtimeDependencies", split(substvars.getProperty("maven.Depends")));
@@ -276,39 +255,10 @@ public class GenerateDebianFilesMojo extends AbstractMojo {
                 context.put("optionalDependencies", split(substvars.getProperty("maven.OptionalDepends")));
                 context.put("javadocDependencies", split(substvars.getProperty("maven.DocDepends")));
                 context.put("javadocOptionalDependencies", split(substvars.getProperty("maven.DocOptionalDepends")));
-
-                if ("ant".equals(packageType)) {
-                    Set<String> compileJars = new TreeSet<String>();
-                    for (String library : compileDepends) {
-                        compileJars.addAll(scanner.listSharedJars(library));
-                    }
-                    context.put("compileJars", compileJars);
-                    Set<String> testJars = new TreeSet<String>();
-                    for (String library : testDepends) {
-                        testJars.addAll(scanner.listSharedJars(library));
-                    }
-                    context.put("testJars", testJars);
-                }
             } else {
                 getLog().warn("Cannot find file " + substvarsFile);
             }
 
-            if ("ant".equals(packageType)) {
-                ListOfPOMs listOfPOMs = new ListOfPOMs(new File(outputDirectory, binPackageName + ".poms"));
-                ListOfPOMs listOfJavadocPOMs = null;
-                if (generateJavadoc && "ant".equals(packageType)) {
-                    listOfJavadocPOMs =  new ListOfPOMs(new File(outputDirectory, binPackageName + "-doc.poms"));
-                }
-                setupArtifactLocation(listOfPOMs, listOfJavadocPOMs, project);
-                for (MavenProject mavenProject : collectedProjects) {
-                    setupArtifactLocation(listOfPOMs, listOfJavadocPOMs, mavenProject);
-                }
-                listOfPOMs.save();
-                if (listOfJavadocPOMs != null) {
-                    listOfJavadocPOMs.save();
-                }
-            }
-
             int downloadType = DownloadType.UNKNOWN;
 
             if (downloadUrl == null) {
@@ -377,16 +327,13 @@ public class GenerateDebianFilesMojo extends AbstractMojo {
                 getLog().warn("Cannot recognize the download url (" + downloadUrl + ").");
             }
 
-            String rulesTemplate = "ant".equals(packageType) ? "rules.ant.vm" : "rules.vm";
-
             generateFile(context, "README.source.vm", outputDirectory, "README.source");
             generateFile(context, "copyright.vm", outputDirectory, "copyright");
-            generateFile(context, "compat.vm", outputDirectory, "compat");
-            generateFile(context, rulesTemplate, outputDirectory, "rules", true);
+            generateFile(context, "rules.vm", outputDirectory, "rules", true);
 
             context.put("version.vm", mangleVersion(project.getVersion()) + "-1");
 
-            generateFile(context, rulesTemplate, new File("."), ".debianVersion");
+            generateFile(context, "rules.vm", new File("."), ".debianVersion");
 
             if (generateJavadoc) {
                 if (project.getPackaging().equals("pom") && collectedProjects.size() > 1) {
@@ -398,37 +345,8 @@ public class GenerateDebianFilesMojo extends AbstractMojo {
                 }
             }
 
-            if ("ant".equals(packageType)) {
-                boolean containsJars = false;
-                boolean containsPlugins = false;
-                if (project.getPackaging().equals("pom") && project.getModules().size() > 0) {
-                    for (MavenProject module : collectedProjects) {
-                        if (module.getPackaging().equals("maven-plugin")) {
-                            containsPlugins = true;
-                        } else if (!module.getPackaging().equals("pom")) {
-                            containsJars = true;
-                        }
-                    }
-                } else if (!project.getPackaging().equals("pom")) {
-                    if (project.getPackaging().equals("maven-plugin")) {
-                        containsPlugins = true;
-                    } else if (!project.getPackaging().equals("pom")) {
-                        containsJars = true;
-                    }
-                }
-                context.put("containsJars", Boolean.valueOf(containsJars));
-                context.put("containsPlugins", Boolean.valueOf(containsPlugins));
-
-                if (project.getPackaging().equals("pom") && project.getModules().size() > 0) {
-                    generateFile(context, "build.xml.vm", outputDirectory, "build.xml");
-                }
-                generateFile(context, "build.properties.ant.vm", outputDirectory, "build.properties");
-                generateFile(context, "build-classpath.vm", outputDirectory, "build-classpath");
-            } else {
-                generateFile(context, "maven.properties.vm", outputDirectory, "maven.properties");
-            }
-
-            generateFile(context, "ant".equals(packageType) ? "control.ant.vm" : "control.vm", outputDirectory, "control");
+            generateFile(context, "maven.properties.vm", outputDirectory, "maven.properties");
+            generateFile(context, "control.vm", outputDirectory, "control");
             generateFile(context, "format.vm", new File(outputDirectory, "source"), "format");
 
         } catch (IOException ex) {
@@ -515,14 +433,6 @@ public class GenerateDebianFilesMojo extends AbstractMojo {
             POMOptions pomOptions = listOfPOMs.getOrCreatePOMOptions(pomFile);
             pomOptions.setArtifact(dirRelPath + "target/" + mavenProject.getArtifactId() + "-*."
                 + extension);
-            if ("jar".equals(extension) && generateJavadoc && "ant".equals(packageType) && listOfJavadocPOMs != null) {
-                String artifactId = mavenProject.getArtifact().getArtifactId();
-                POMOptions javadocPomOptions = listOfJavadocPOMs.getOrCreatePOMOptions(pomFile);
-                javadocPomOptions.setIgnorePOM(true);
-                javadocPomOptions.setArtifact(dirRelPath + "target/" + artifactId + ".javadoc.jar");
-                javadocPomOptions.setClassifier("javadoc");
-                javadocPomOptions.setHasPackageVersion(pomOptions.getHasPackageVersion());
-            }
             pomOptions.setJavaLib(true);
             if (mavenProject.getArtifactId().matches(packageName + "\\d")) {
                 pomOptions.setUsjName(packageName);
